# Tutorials

## Reading refractive index data
`SellmeierFit.read()` reads refractive index data, and outputs wavelengths ``λ`` and dielectric constants ``ε_\mathrm{r}``.  The function supports various keyword arguments to read refractive index data in various formats.  See [`SellmeierFit.read()`](@ref) for the details of available keyword arguments.

### From a CSV file
Suppose a CSV file named `refindex.csv` in the present working directory contains wavelengths ``λ`` in units of µm and the corresponding refractive indices ``n`` as the first and second columns, respectively.  The following code stores wavelengths in units of meters (not µm) and dielectric constants in variables `λ` and `ε` via [property destructuring of `NamedTuple`](https://julialang.org/blog/2021/11/julia-1.7-highlights/#property_destructuring):
```julia
(; λ, ε) = SellmeierFit.read("refindex.csv")
```
`λ` and `ε` can be equally obtained by
```julia
result = SellmeierFit.read("refindex.csv")
λ = result.λ
ε = result.ε
```
or
```julia
result = SellmeierFit.read("refindex.csv")
λ = result[1]
ε = result[2]
```
Only the first method using property destructuring will be discussed in the following sections, but the other methods are applicable there as well.

### From a text file
Suppose a text file named `refindex.txt` contains wavelengths in units of µm and the corresponding refractive indices as follows:
```
Refractive Index
wl 	n
0.21	1.53835762
0.2174	1.530846431
0.2251	1.524078907
0.233	1.518041768
0.2412	1.512572116
...
```
In this case, the information that the first two lines of the file are a header needs to be provided to `SellmeierFit.read()`:
```julia
(; λ, ε) = SellmeierFit.read(path, header=2)
```

### From a website
Websites such as [RefractiveIndex.info](https://refractiveindex.info) provide refractive index data of various materials in CSV format.  The link to these data files can be directly passed to `SellmeierFit.read()`:
```julia
(; λ, ε) = SellmeierFit.read("https://refractiveindex.info/tmp/data/main/SiO2/Malitson.csv")
```

## Fitting data to the Sellmeier equation
Once you have a vector `λ` of wavelengths in units of meters and a vector `ε` of dielectric constants, fitting these data to the Sellmeier equation is performed by
```julia
(; mdl, err) = fit_sellmeier(λ, ε)
```
Here, `mdl` is an instance of `SellmeierModel` that has `str` and `λres` as fields; they represent the strengths and resonance wavelengths of the terms in the Sellmeier equation, and correspond to ``B_i``'s and ``\sqrt{C_i}``'s, resectively.  `err` is the root-mean-square error of the entries of `ε` with respect to the fitting Sellmeier equation.

## Concrete examples
Concrete example scripts are included in the `example/` directory.  Here is the plot generated by `example/from_csv.jl`:
![SiO₂](assets/SiO₂.png)
Note that the fitting Sellmeier equation passes through all the data points almost exactly.  The calculated fitting parameters are
```julia-repl
B = [0.6961663000454741, 0.40794259995450777, 0.897479399999896]
√C = [0.06840430000255329, 0.11624140000172782, 9.896160999999745]
```
and agree well with the values shown in the Dispersion formula section [here](https://refractiveindex.info/?shelf=main&book=SiO2&page=Malitson).
